# -*- coding: utf-8 -*-

FIAT_CURRENCY_AUD = u"AUD"
FIAT_CURRENCY_BRL = u"BRL"
FIAT_CURRENCY_CAD = u"CAD"
FIAT_CURRENCY_CHF = u"CHF"
FIAT_CURRENCY_CLP = u"CLP"
FIAT_CURRENCY_CNY = u"CNY"
FIAT_CURRENCY_CZK = u"CZK"
FIAT_CURRENCY_DKK = u"DKK"
FIAT_CURRENCY_EUR = u"EUR"
FIAT_CURRENCY_GBP = u"GBP"
FIAT_CURRENCY_HKD = u"HKD"
FIAT_CURRENCY_HUF = u"HUF"
FIAT_CURRENCY_IDR = u"IDR"
FIAT_CURRENCY_ILS = u"ILS"
FIAT_CURRENCY_INR = u"INR"
FIAT_CURRENCY_JPY = u"JPY"
FIAT_CURRENCY_KRW = u"KRW"
FIAT_CURRENCY_MXN = u"MXN"
FIAT_CURRENCY_MYR = u"MYR"
FIAT_CURRENCY_NOK = u"NOK"
FIAT_CURRENCY_NZD = u"NZD"
FIAT_CURRENCY_PHP = u"PHP"
FIAT_CURRENCY_PKR = u"PKR"
FIAT_CURRENCY_PLN = u"PLN"
FIAT_CURRENCY_RUB = u"RUB"
FIAT_CURRENCY_SEK = u"SEK"
FIAT_CURRENCY_SGD = u"SGD"
FIAT_CURRENCY_THB = u"THB"
FIAT_CURRENCY_TRY = u"TRY"
FIAT_CURRENCY_TWD = u"TWD"
FIAT_CURRENCY_ZAR = u"ZAR"

CRYPTO_CURRENCY_BTC = u"BTC"
CRYPTO_CURRENCY_ETH = u"ETH"
CRYPTO_CURRENCY_XRP = u"XRP"
CRYPTO_CURRENCY_LTC = u"LTC"
CRYPTO_CURRENCY_BCH = u"BCH"
